import { Component, OnInit } from '@angular/core';
import { UserService } from './user/services';
import { Router, NavigationEnd } from '@angular/router';
import { filter } from 'rxjs/operators';
import { NavigationHistoryService } from './services';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss'],
})
export class AppComponent implements OnInit {

  title: string;
  sidebarOpened: boolean;
  userDropdownIsOpened = false;

  constructor(
    private _userService: UserService,
    private _router: Router,
    private _navigationHistoryService: NavigationHistoryService,
  ) { }

  ngOnInit(): void {
    this.sidebarOpened = true;

    // Activate navigation history
    this._router.events.pipe(
      filter(e => e instanceof NavigationEnd),
    ).subscribe((e) => {
      this._navigationHistoryService.add(e['urlAfterRedirects']);
    });
  }

  get loggedInUserFullname() {
    return this._userService.user ? `${this._userService.user.firstName} ${this._userService.user.lastName}` : null;
  }

  loggout() {
    console.log('blabla')
    this._userService.resetAuth();
    this.closeUserDropdown();
    this._router.navigate(['/login']);
  }

  toggleUserDropdown() {
    this.userDropdownIsOpened = !this.userDropdownIsOpened;
  }

  closeUserDropdown() {
    this.userDropdownIsOpened = false;
  }
}
