export class Organization {
  id: number;
  name: string;
  description: string;
  elasticSearchName?: string;
  logo?: string;
  links?: ILink[];

  constructor(organization?: IOrganization) {
    if (organization) {
      if (organization.id) {
        this.id = organization.id;
      }
      this.name = organization.name;
      this.description = organization.description;
      this.elasticSearchName = organization.elasticSearchName;
      this.links = organization.links;

      this.links.forEach((link) => {
        if (!link.id) {
          delete link.id;
        }
      });
      this.logo = organization.logo;
    } else {
      this.name = null;
      this.description = null;
      this.logo = null;
      this.elasticSearchName = null;
      this.links = [];
    }

  }
}

export class OrganizationRO {
  organizations: Organization[];
  totalCount: number;

  constructor(organizations, totalCount) {
    this.organizations = organizations;
    this.totalCount = totalCount;
  }
}

export interface IOrganization {
  id: number;
  name: string;
  description: string;
  elasticSearchName: string;
  logo: string;
  links: ILink[];
}

interface ILink {
  id?: number;
  name: string;
  url: string;
  organizationId: number;
}
